@@ -2,7 +2,7 @@ package org.gcube.portlets.user.wsmail.client;
 
 import java.util.ArrayList;
 
-import org.gcube.portlets.user.wsmail.server.CurrUserAndPortalUsersWrapper;
+import org.gcube.portlets.user.wsmail.shared.CurrUserAndPortalUsersWrapper;
 import org.gcube.portlets.user.wsmail.shared.WSUser;
 
 import com.google.gwt.user.client.rpc.AsyncCallback;
